@@ -1,9 +1,9 @@
-import numpy as np
 import pandas as pd
 import os, pickle
 from sklearn.preprocessing import StandardScaler, MinMaxScaler, RobustScaler
 import math
 import glob
+from datetime import timedelta
 import dask.dataframe as dd
 import warnings
 warnings.filterwarnings('ignore')
@@ -11,7 +11,7 @@ from nilm_analyzer.modules.parser import refit_parser, ukdale_parser, ampds_pars
 from nilm_analyzer.modules.validations import check_house_availability, check_list_validations, check_correct_datatype
 from nilm_analyzer.modules.active_durations import get_activities
 from nilm_analyzer.utilities import convert_object2timestamps, get_module_directory
-    
+
 class __Loader:
     """
     Interface that loads all the data into the memory
@@ -167,7 +167,8 @@ class REFIT_Loader(CSV_Loader):
                 
         finally:
             # self.__config = get_config_from_json(description="refit_loader configuration", config_file='../refit_loader/config.json')
-            self.__config = {'DATA_FOLDER': os.path.join(os.getcwd(), data_path), 'DATA_TYPE':'.csv', 'METADATA': os.path.join(get_module_directory(), 'metadata', 'refit'),
+            self.__config = {'DATA_FOLDER': os.path.join(os.getcwd(), data_path), 'DATA_TYPE':'.csv', 'METADATA': os.path.join(get_module_directory(),
+                                                                                                                               'metadata', 'refit'),
                              'REFIT_HOUSES': [1,2,3,4,5,6,7,8,9,10,11,12,13,15,16,17,18,19,20,21]}
             self.__keys_of_appliances = refit_parser(_buildings=self.__config['REFIT_HOUSES'], _metadata=self.__config['METADATA'])
             self.__collective_dataset = CSV_Loader._load_files_via_dask(_data_folder=self.__config['DATA_FOLDER'],
@@ -307,7 +308,8 @@ class UKDALE_Loader(CSV_Loader):
             print("Error occured in initialization of UKDALE_Loader class due to ", e)
 
         finally:
-            self.__config = {'DATA_FOLDER': os.path.join(os.getcwd(), data_path), 'DATA_TYPE':'.dat', 'METADATA': os.path.join(get_module_directory(), 'metadata', 'ukdale'),
+            self.__config = {'DATA_FOLDER': os.path.join(os.getcwd(), data_path), 'DATA_TYPE':'.dat', 'METADATA': os.path.join(get_module_directory(),
+                                                                                                                               'metadata', 'ukdale'),
                              'UKDALE_HOUSES': [1,2,3,4,5]}
             self.__keys_of_appliances = ukdale_parser(_buildings=self.__config['UKDALE_HOUSES'], _metadata=self.__config['METADATA'])
             self.__collective_dataset = CSV_Loader._load_files_via_dask_channel_wise(_data_folder=self.__config['DATA_FOLDER'],
@@ -591,7 +593,8 @@ class IAWE_Loader(CSV_Loader):
             print("Error occured in initialization of IAWE_Loader class due to ", e)
 
         finally:
-            self.__config = {'DATA_FOLDER': os.path.join(os.getcwd(), data_path), 'DATA_TYPE':'.csv', 'METADATA': os.path.join(get_module_directory(), 'metadata', 'iawe'),
+            self.__config = {'DATA_FOLDER': os.path.join(os.getcwd(), data_path), 'DATA_TYPE':'.csv', 'METADATA': os.path.join(get_module_directory(),
+                                                                                                                               'metadata', 'iawe'),
                              'IAWE_HOUSES': [1]}
             self.__keys_of_appliances = iawe_parser(_buildings=self.__config['IAWE_HOUSES'], _metadata=self.__config['METADATA'])
             self.__collective_dataset = CSV_Loader._load_files_via_dask_channel_wise(_data_folder=self.__config['DATA_FOLDER'],
@@ -746,7 +749,8 @@ class DEDDIAG_LOADER(CSV_Loader):
             print("Error occured in initialization of DEDDIAG_LOADER class due to ", e)
 
         finally:
-            self.__config = {'DATA_FOLDER': os.path.join(os.getcwd(), data_path), 'DATA_TYPE':'.tsv', 'METADATA': os.path.join(get_module_directory(), 'metadata', 'deddiag'),
+            self.__config = {'DATA_FOLDER': os.path.join(os.getcwd(), data_path), 'DATA_TYPE':'.tsv', 'METADATA': os.path.join(get_module_directory(),
+                                                                                                                               'metadata', 'deddiag'),
                              'DEDDIAG_HOUSES': ['00','01', '02', '03', '04', '05', '06', '07','08', '09', '10', '11', '12', '13', '14']}
             self.__keys_of_appliances = deddiag_parser(_buildings=self.__config['DEDDIAG_HOUSES'], _metadata=self.__config['METADATA'])
             self.__collective_dataset = CSV_Loader._load_files_via_dask_channel_wise(_data_folder=self.__config['DATA_FOLDER'],
@@ -891,7 +895,8 @@ class GELAP_Loader(CSV_Loader):
             print("Error occured in initialization of GELAP_Loader class due to ", e)
 
         finally:
-            self.__config = {'DATA_FOLDER': os.path.join(os.getcwd(), data_path), 'DATA_TYPE':'.csv', 'METADATA': os.path.join(get_module_directory(), 'metadata', 'gelap'),
+            self.__config = {'DATA_FOLDER': os.path.join(os.getcwd(), data_path), 'DATA_TYPE':'.csv', 'METADATA': os.path.join(get_module_directory(),
+                                                                                                                               'metadata', 'gelap'),
                              'GELAP_HOUSES': ['01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11',
                                                 '12', '13', '14', '15', '16', '17', '18', '19', '20']}
             self.__keys_of_appliances = gelap_parser(_buildings=self.__config['GELAP_HOUSES'], _metadata=self.__config['METADATA'])
@@ -1037,7 +1042,7 @@ class _EnergyDataset():
         finally:
             pass
     
-    def resample(self, sampling_period=None, window_limit=2.0, fill_value=0.0):
+    def resample(self, sampling_period=None, window_limit=3.0, fill_value=0.0):
         """
         This method will return _EnergyDataset object that can let user access data in dictionary format as well can access some transformation methods
 
@@ -1066,17 +1071,20 @@ class _EnergyDataset():
                         }
         """
         try:
-            self.__sampling_period = sampling_period
+
             self.__fill_value = fill_value
-            self.__window_limit= int(window_limit*60)
 
             for house_number in self.data.keys():
                 print(f"Resampling for house number: ", house_number)
 #                     target_appliance = self.data[house_number].columns[-1]
                 appliance_data = self.data[house_number]
-                if self.__sampling_period is None:
+                if sampling_period is None:
                     delta = appliance_data.index[1] - appliance_data.index[0]
-                    self.__sampling_period = str(delta.seconds) + 's'
+                    self.__sampling_period = str(int(delta.seconds)) + 's'
+                    self.__window_limit = int((window_limit * 60) / delta.seconds)
+                else:
+                    self.__sampling_period = str(int(sampling_period)) + 's'
+                    self.__window_limit = int((window_limit * 60) / sampling_period)
                 print(f'sampling_period = {self.__sampling_period}, window_limit = {self.__window_limit} samples, fill_value = {self.__fill_value}\n')
                 appliance_data = appliance_data[~appliance_data.index.duplicated(keep='first')]
 #                     appliance_data = appliance_data.resample('1s').mean().dropna()
@@ -1092,19 +1100,19 @@ class _EnergyDataset():
             print("Error occured in resample method of _EnergyDataset due to ", e)
             
 
-    def get_activations(self, threshold_x=None):
+    def get_activations(self, target_appliance=None, threshold_x=None, threshold_y=None, min_limit=None, max_limit=None):
 
         try:
             for house_number, value in self.data.items():
                 print(f"Extracting activations for House {house_number}")
-                self.activations.update({house_number: get_activities(value, threshold_x) })
+                self.activations.update({house_number: get_activities(value, target_appliance, threshold_x, threshold_y, min_limit, max_limit) })
             print("Updating activations with durations when appliance is active (above threshold).")
 
         except Exception as e:
             print("Error occured in get_activations method of _EnergyDataset due to ", e)
 
 
-    def subset_data(self, no_of_days=5, threshold = None ):
+    def subset_data(self, no_of_days=5, best_days=False, target_appliance=None, threshold_x=None, threshold_y=None, min_limit=None, max_limit=None):
         """
         This method will create different and smaller versions of the training, validation and testing subsets from the collective_data
 
@@ -1129,15 +1137,19 @@ class _EnergyDataset():
         try:
             self.__no_of_days = no_of_days
             for house_number, value in self.data.items():
-                print(f"Subetting dataset with {self.__no_of_days} days of most activities for House {house_number}")
-                activities = get_activities(value)
-                date_wise_activities = activities.groupby([activities['activity_start'].dt.date]).sum()
-                time_indices = date_wise_activities.sort_values('duration_in_seconds', ascending=False).head(self.__no_of_days).index
-                df_outer = pd.DataFrame()
-                for version, time_indx in enumerate(time_indices):
-                    df_outer = pd.concat([df_outer, value.loc[str(time_indx)]])
-                df_outer.sort_index(inplace=True)
-                self.data.update({house_number: df_outer})
+                print(f"Subetting dataset with {self.__no_of_days} days of data for House {house_number}")
+                if best_days:
+                    activities = get_activities(value, target_appliance, threshold_x, threshold_y, min_limit, max_limit)
+                    date_wise_activities = activities.groupby([activities['activity_start'].dt.date]).sum()
+                    time_indices = date_wise_activities.sort_values('duration_in_minutes', ascending=False).head(self.__no_of_days).index
+                    df_outer = pd.DataFrame()
+                    for version, time_indx in enumerate(time_indices):
+                        df_outer = pd.concat([df_outer, value.loc[str(time_indx)]])
+                    df_outer.sort_index(inplace=True)
+                    self.data.update(
+                        {house_number: df_outer})
+                else:
+                    self.data.update({house_number: value.loc[str(value.index[0]):str(value.index[0]+ timedelta(days=no_of_days))]})
             print("Updating data with selected active appliance activities...")
 
         except Exception as e:
