@@ -6,7 +6,7 @@ from datetime import timedelta
 from nilm_analyzer.utilities import convert_object2timestamps
 
 
-def __generate_activity_report(df, target_appliance, threshold_x, threshold_y):
+def __generate_activity_report(df, target_appliance, threshold_x, threshold_y, min_limit, max_limit):
     """
     This method will return the durations or events when the appliance was active (on) 
     
@@ -57,9 +57,11 @@ def __generate_activity_report(df, target_appliance, threshold_x, threshold_y):
             d = df_tmp.loc[(x)].reset_index()
             duration_start.append(d.iloc[0][str(df.index.name)])
             duration_end.append(d.iloc[-1][str(df.index.name)])
-            duration_size.append(duration_end[-1] - duration_start[-1])
-        durations = (pd.Series(duration_size)) / np.timedelta64(1, 's')
-        activities =  pd.DataFrame({'start': duration_start, 'end': duration_end, 'duration_in_seconds': durations})
+            # duration_size.append(duration_end[-1] - duration_start[-1])
+        # durations = (pd.Series(duration_size)) / np.timedelta64(1, 's')
+        # durations = pd.Series(duration_size)
+        activities =  pd.DataFrame({'start': duration_start, 'end': duration_end})
+                                    # ,'duration_in_minutes': durations})
 
         prev_act_end = activities['end'][:-1]
         next_act_st = activities['start'][1:]
@@ -70,23 +72,34 @@ def __generate_activity_report(df, target_appliance, threshold_x, threshold_y):
 
         delta = next_act_st[next_act_st.columns[-1]] - prev_act_end[prev_act_end.columns[-1]]
 
-        mask = delta < timedelta(minutes=30)
+        mask = delta < timedelta(minutes=threshold_x)
         mask = mask.shift(periods=1, fill_value=True)
         activities['low_delta'] = (mask)
         activities['cum_sum'] = (~mask).cumsum()
 
         start = activities.groupby(['cum_sum'])['start'].first()
         end = activities.groupby(['cum_sum'])['end'].last()
-        duration_in_seconds = activities.groupby(['cum_sum'])['duration_in_seconds'].sum()
-        duration_df = pd.DataFrame({'activity_start': start, 'activity_end': end, 'duration_in_seconds': duration_in_seconds})
-        return duration_df[duration_df['duration_in_seconds']>30.0]
+        duration_in_minutes = (end - start)/ np.timedelta64(1, 'm')
+        # duration_in_minutes = activities.groupby(['cum_sum'])['duration_in_minutes'].sum()
+        duration_df = pd.DataFrame({'activity_start': start, 'activity_end': end, 'duration_in_minutes': duration_in_minutes})
+        duration_df.reset_index(inplace=True)
+        duration_df.drop(columns=['cum_sum'], inplace=True)
+        if min_limit is None:
+            min_limit = 3.0
+        if max_limit is None:
+            max_limit = 240.0
+        df = duration_df[(duration_df['duration_in_minutes'] > min_limit)]
+        df = df[(df['duration_in_minutes'] < max_limit)]
+        df.reset_index(inplace=True)
+        df.drop(columns=['index'], inplace=True)
+        return df
     
     except Exception as e:
         print("Exception raised in generate_activity_report() method = ", e)
 
 
         
-def get_activities(data, target_appliance=None, threshold_x=None, threshold_y=None):
+def get_activities(data, target_appliance=None, threshold_x=None, threshold_y=None, min_limit=None, max_limit=None):
     """
     This method will call the generate_activity_report for every dataframe to compute the durations of the active appliance and append to either a dictionary or returns back the single dataframe
     
@@ -144,16 +157,18 @@ def get_activities(data, target_appliance=None, threshold_x=None, threshold_y=No
                     else:
                         raise Exception(f"Please specify target appliance {df.columns}")
                 if threshold_y is None:
-                    threshold_y = 0.02 * df[target_appliance].max()
-                    print(f'Consumption Threshold is set to = {threshold_y}')
+                    threshold_y = 0.04 * df[target_appliance].max()
+                # else:
+                #     threshold_y = threshold_y * df[target_appliance].max()
+                print(f'Consumption Threshold is set to = {threshold_y}')
                 if threshold_x is None:
                     if target_appliance == 'kettle':
                         threshold_x = 5.0
                     else:
                         threshold_x = 30.0
-                    print(f'Time Delay Threshold is set to = {threshold_x} minutes')
+                print(f'Time Delay Threshold is set to = {threshold_x} minutes')
                 print(f"Estimating active durations of House {key}: {target_appliance}")
-                house_activities.update({key: __generate_activity_report(df, target_appliance, threshold_x, threshold_y)})
+                house_activities.update({key: __generate_activity_report(df, target_appliance, threshold_x, threshold_y, min_limit, max_limit)})
 
             return house_activities
         
@@ -169,15 +184,17 @@ def get_activities(data, target_appliance=None, threshold_x=None, threshold_y=No
                     raise Exception(f"Please specify target_appliance \n {data.columns}")
             if threshold_y is None:
                 threshold_y = 0.02 * data[target_appliance].max()
-                print(f'Consumption Threshold is set to = {threshold_y}')
+            # else:
+            #     threshold_y = threshold_y * data[target_appliance].max()
+            print(f'Consumption Threshold is set to = {threshold_y}')
             if threshold_x is None:
                 if target_appliance == 'kettle':
                     threshold_x = 5.0
                 else:
                     threshold_x = 30.0
-                print(f'Time Delay Threshold is set to = {threshold_x} minutes')
+            print(f'Time Delay Threshold is set to = {threshold_x} minutes')
             print(f"Estimating active durations of: {target_appliance}")
-            return __generate_activity_report(data, target_appliance, threshold_x, threshold_y)
+            return __generate_activity_report(data, target_appliance, threshold_x, threshold_y, min_limit, max_limit)
 
         else:
             print(f"Provided data should be of type <dict> or <pandas.core.frame.DataFrame> and not {type(data)}.")
